#include <assert.h>
#include "cli.h"

static cli_field_descriptor quality_group_descriptor[] = {
  {3 /*SmallInt*/  , 1,"QualityID"   ,NULL    ,NULL},
  {10/*String*/    , 0,"QualityGroup",NULL    ,NULL},
  {2 /*Byte*/      , 0,"MinQuality"  ,NULL    ,NULL},
  {2 /*Byte*/      , 0,"MaxQuality"  ,NULL    ,NULL},
  {12/*ArrayOfOID*/, 0,"Demands"     ,"Demand","QualityGroups"}};

static cli_field_descriptor demand_descriptor[] = {
    {0 /*(oid)*/      , 0,"Switch"          ,"Switch"      ,"Demands"},
    {0 /*(oid)*/      , 0,"Location"        ,"Location"    ,"Demands"},
    {5 /*Int64*/      , 1,"SwitchLocationID",NULL          ,NULL},
    {12/*ArrayOfOID*/ , 0,"QualityGroups"   ,"QualityGroup","Demands"},
    {16/*ArrayOfInt4*/, 0,"Demands"         ,NULL          ,NULL}};

static cli_field_descriptor switch_descriptor[] = {
    {3  /*SmallInt*/    , 1, "SwitchID",   NULL, NULL},
    {10 /*String*/      , 0, "SwitchName", NULL, NULL},
    {12 /*ArrayOfOID*/  , 0, "Carriers",   "Carrier", "Switch"},
    {12 /*ArrayOfOID*/  , 0, "Demands",    "Demand", "Switch"},
         {12 /*ArrayOfOID*/  , 0, "Rates",      "Rate", "Switch"}
};

static cli_field_descriptor location_descriptor[] = {
    {4  /*Integer*/     , 1, "LocationID",   NULL, NULL},
    {10 /*String*/      , 0, "LocationName", NULL, NULL},
    {12 /*ArrayOfOID*/  , 0, "Rates",        "Rate", "Location"},
    {12 /*ArrayOfOID*/  , 0, "Demands",      "Demand", NULL}
};

static cli_field_descriptor carrier_descriptor[] = {
    {0  /*(oid)*/       , 0, "Switch",     "Switch", "Carriers"},
    {4  /*Integer*/     , 1, "CarrierID",         NULL, NULL},
    {5  /*Int64*/       , 1, "SwitchCarrierID",   NULL, NULL},
    {10 /*String*/      , 0, "CarrierName",       NULL, NULL},
    {12 /*ArrayOfOID*/  , 0, "Rates",             "Rate", "Carrier"},
    {4  /*Integer*/     , 0, "TotalCapacity",     NULL, NULL},
    {4  /*Integer*/     , 0, "AvailableCapacity", NULL, NULL},
    {3  /*SmallInt*/    , 0, "TotalLines",        NULL, NULL},
    {3  /*SmallInt*/    , 0, "AvailableLines",    NULL, NULL}
};

static cli_field_descriptor rate_descriptor[] = {
    {0  /*(oid)*/    , 0, "Switch",            "Switch", "Rates"},
    {0  /*(oid)*/    , 0, "Location",          "Location", "Rates"},
    {0  /*(oid)*/    , 0, "Carrier",          "Carrier", "Rates"},
    {5  /*Int64*/    , 1, "CarrierLocationID", NULL, NULL},
    {2  /*Byte*/     , 0, "Quality",           NULL, NULL},
    {6  /*Single*/   , 0, "Rate",              NULL, NULL},
    {4  /*Integer*/  , 0, "RealDemand",        NULL, NULL}
};

int main(int argc, char* argv[]) {
    char* databaseName = "clitest";
    char* filePath = "clitest.fdb";
    int session;
    cli_field_descriptor** p;
    if (argc < 3) {
      printf("Usage: TestRefTables InitDatabaseSize InitIndexSize (all in kBytes)\n");
      exit(-1);
    }
    session = cli_create(databaseName, filePath, 0, 0, atoi(argv[1])*1024, 4*1024*1024, atoi(argv[2])*1024, 0);
    cli_create_table(session, "QualityGroup", 5, quality_group_descriptor);
    cli_commit(session);
    cli_create_table(session, "Demand",       5, demand_descriptor);
    cli_create_table(session, "Switch",       5, switch_descriptor);
    cli_create_table(session, "Location",     4, location_descriptor);
    cli_describe(session, "Switch", p);
    cli_free_memory(session, *p);
    cli_create_table(session, "Carrier",      9, carrier_descriptor);
    cli_create_table(session, "Rate",         7, rate_descriptor);
    cli_close(session);
    return 0;
}
